@@ -11,6 +11,7 @@ use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Profiling;
 use PhpMyAdmin\Server\SysInfo\SysInfo;
 use PhpMyAdmin\Util;
+
 use function array_sum;
 use function count;
 use function implode;
@@ -114,12 +115,10 @@ class Monitor
                 foreach ($nodeDataPoints as $point_id => $dataPoint) {
                     switch ($dataPoint['type']) {
                         case 'statusvar':
-                            $ret[$chart_id][$node_id][$point_id]['value']
-                            = $statusVarValues[$dataPoint['name']];
+                            $ret[$chart_id][$node_id][$point_id]['value'] = $statusVarValues[$dataPoint['name']];
                             break;
                         case 'servervar':
-                            $ret[$chart_id][$node_id][$point_id]['value']
-                            = $serverVarValues[$dataPoint['name']];
+                            $ret[$chart_id][$node_id][$point_id]['value'] = $serverVarValues[$dataPoint['name']];
                             break;
                     }
                 }
@@ -155,17 +154,16 @@ class Monitor
             foreach ($chartNodes as $nodeId => $nodeDataPoints) {
                 // For each data point in the series (usually just 1)
                 foreach ($nodeDataPoints as $pointId => $dataPoint) {
-                    [$serverVars, $statusVars, $ret[$chartId][$nodeId][$pointId]]
-                        = $this->getJsonForChartingDataSwitch(
-                            $dataPoint['type'],
-                            $dataPoint['name'],
-                            $serverVars,
-                            $statusVars,
-                            $ret[$chartId][$nodeId][$pointId],
-                            $sysinfo,
-                            $cpuload,
-                            $memory
-                        );
+                    [$serverVars, $statusVars, $ret[$chartId][$nodeId][$pointId]] = $this->getJsonForChartingDataSwitch(
+                        $dataPoint['type'],
+                        $dataPoint['name'],
+                        $serverVars,
+                        $statusVars,
+                        $ret[$chartId][$nodeId][$pointId],
+                        $sysinfo,
+                        $cpuload,
+                        $memory
+                    );
                 } /* foreach */
             } /* foreach */
         }
@@ -201,33 +199,35 @@ class Monitor
         $cpuload,
         $memory
     ) {
+        /**
+         * We only collect the status and server variables here to read them all in one query,
+         * and only afterwards assign them. Also do some allow list filtering on the names
+         */
         switch ($type) {
-        /* We only collect the status and server variables here to
-         * read them all in one query,
-         * and only afterwards assign them.
-         * Also do some allow list filtering on the names
-        */
             case 'servervar':
                 if (! preg_match('/[^a-zA-Z_]+/', $pName)) {
                     $serverVars[] = $pName;
                 }
+
                 break;
 
             case 'statusvar':
                 if (! preg_match('/[^a-zA-Z_]+/', $pName)) {
                     $statusVars[] = $pName;
                 }
+
                 break;
 
             case 'proc':
                 $result = $this->dbi->query('SHOW PROCESSLIST');
-                $ret['value'] = $this->dbi->numRows($result);
+                $ret['value'] = $result->numRows();
                 break;
 
             case 'cpu':
                 if (! $sysinfo) {
                     $sysinfo = SysInfo::get();
                 }
+
                 if (! $cpuload) {
                     $cpuload = $sysinfo->loadavg();
                 }
@@ -245,6 +245,7 @@ class Monitor
                 if (! $sysinfo) {
                     $sysinfo = SysInfo::get();
                 }
+
                 if (! $memory) {
                     $memory = $sysinfo->memory();
                 }
@@ -265,12 +266,10 @@ class Monitor
      *
      * @param int $start Unix Time: Start time for query
      * @param int $end   Unix Time: End time for query
-     *
-     * @return array
      */
-    public function getJsonForLogDataTypeSlow(int $start, int $end): array
+    public function getJsonForLogDataTypeSlow(int $start, int $end): ?array
     {
-        $query  = 'SELECT start_time, user_host, ';
+        $query = 'SELECT start_time, user_host, ';
         $query .= 'Sec_to_Time(Sum(Time_to_Sec(query_time))) as query_time, ';
         $query .= 'Sec_to_Time(Sum(Time_to_Sec(lock_time))) as lock_time, ';
         $query .= 'SUM(rows_sent) AS rows_sent, ';
@@ -278,16 +277,20 @@ class Monitor
         $query .= 'COUNT(sql_text) AS \'#\' ';
         $query .= 'FROM `mysql`.`slow_log` ';
         $query .= 'WHERE start_time > FROM_UNIXTIME(' . $start . ') ';
-        $query .= 'AND start_time < FROM_UNIXTIME(' . $end . ') GROUP BY sql_text';
+        // See: mode = ONLY_FULL_GROUP_BY
+        $query .= 'AND start_time < FROM_UNIXTIME(' . $end . ') GROUP BY start_time, user_host, db, sql_text';
 
         $result = $this->dbi->tryQuery($query);
+        if ($result === false) {
+            return null;
+        }
 
         $return = [
             'rows' => [],
             'sum' => [],
         ];
 
-        while ($row = $this->dbi->fetchAssoc($result)) {
+        while ($row = $result->fetchAssoc()) {
             $type = mb_strtolower(
                 mb_substr(
                     $row['sql_text'],
@@ -312,6 +315,7 @@ class Monitor
                         $row['sql_text'] = mb_substr($row['sql_text'], 0, 200)
                             . '... [' . $implodeSqlText . ']';
                     }
+
                     break;
                 default:
                     break;
@@ -320,6 +324,7 @@ class Monitor
             if (! isset($return['sum'][$type])) {
                 $return['sum'][$type] = 0;
             }
+
             $return['sum'][$type] += $row['#'];
             $return['rows'][] = $row;
         }
@@ -327,27 +332,23 @@ class Monitor
         $return['sum']['TOTAL'] = array_sum($return['sum']);
         $return['numRows'] = count($return['rows']);
 
-        $this->dbi->freeResult($result);
-
         return $return;
     }
 
     /**
-     * Returns JSon for log data with type: general
+     * Returns JSON for log data with type: general
      *
      * @param int  $start           Unix Time: Start time for query
      * @param int  $end             Unix Time: End time for query
      * @param bool $isTypesLimited  Whether to limit types or not
      * @param bool $removeVariables Whether to remove variables or not
-     *
-     * @return array
      */
     public function getJsonForLogDataTypeGeneral(
         int $start,
         int $end,
         bool $isTypesLimited,
         bool $removeVariables
-    ): array {
+    ): ?array {
         $limitTypes = '';
         if ($isTypesLimited) {
             $limitTypes = 'AND argument REGEXP \'^(INSERT|SELECT|UPDATE|DELETE)\' ';
@@ -359,9 +360,13 @@ class Monitor
         $query .= 'WHERE command_type=\'Query\' ';
         $query .= 'AND event_time > FROM_UNIXTIME(' . $start . ') ';
         $query .= 'AND event_time < FROM_UNIXTIME(' . $end . ') ';
-        $query .= $limitTypes . 'GROUP by argument'; // HAVING count > 1';
+        // See: mode = ONLY_FULL_GROUP_BY
+        $query .= $limitTypes . 'GROUP by event_time, user_host, thread_id, server_id, argument'; // HAVING count > 1';
 
         $result = $this->dbi->tryQuery($query);
+        if ($result === false) {
+            return null;
+        }
 
         $return = [
             'rows' => [],
@@ -371,38 +376,41 @@ class Monitor
         $insertTablesFirst = -1;
         $i = 0;
 
-        while ($row = $this->dbi->fetchAssoc($result)) {
+        while ($row = $result->fetchAssoc()) {
             preg_match('/^(\w+)\s/', $row['argument'], $match);
             $type = mb_strtolower($match[1]);
 
             if (! isset($return['sum'][$type])) {
                 $return['sum'][$type] = 0;
             }
+
             $return['sum'][$type] += $row['#'];
 
             switch ($type) {
-            /** @noinspection PhpMissingBreakStatementInspection */
+                /** @noinspection PhpMissingBreakStatementInspection */
                 case 'insert':
                     // Group inserts if selected
-                    if ($removeVariables
-                    && preg_match(
-                        '/^INSERT INTO (`|\'|"|)([^\s\\1]+)\\1/i',
-                        $row['argument'],
-                        $matches
-                    )
+                    if (
+                        $removeVariables && preg_match(
+                            '/^INSERT INTO (`|\'|"|)([^\s\\1]+)\\1/i',
+                            $row['argument'],
+                            $matches
+                        )
                     ) {
+                        if (! isset($insertTables[$matches[2]])) {
+                            $insertTables[$matches[2]] = 0;
+                        }
+
                         $insertTables[$matches[2]]++;
                         if ($insertTables[$matches[2]] > 1) {
-                            $return['rows'][$insertTablesFirst]['#']
-                                = $insertTables[$matches[2]];
+                            $return['rows'][$insertTablesFirst]['#'] = $insertTables[$matches[2]];
 
                             // Add a ... to the end of this query to indicate that
                             // there's been other queries
                             $temp = $return['rows'][$insertTablesFirst]['argument'];
-                            $return['rows'][$insertTablesFirst]['argument']
-                                .= $this->getSuspensionPoints(
-                                    $temp[strlen($temp) - 1]
-                                );
+                            $return['rows'][$insertTablesFirst]['argument'] .= $this->getSuspensionPoints(
+                                $temp[strlen($temp) - 1]
+                            );
 
                             // Group this value, thus do not add to the result list
                             continue 2;
@@ -411,6 +419,7 @@ class Monitor
                         $insertTablesFirst = $i;
                         $insertTables[$matches[2]] += $row['#'] - 1;
                     }
+
                     // No break here
 
                 case 'update':
@@ -429,6 +438,7 @@ class Monitor
                         )
                             . ']';
                     }
+
                     break;
 
                 default:
@@ -442,8 +452,6 @@ class Monitor
         $return['sum']['TOTAL'] = array_sum($return['sum']);
         $return['numRows'] = count($return['rows']);
 
-        $this->dbi->freeResult($result);
-
         return $return;
     }
 
@@ -480,9 +488,7 @@ class Monitor
             }
 
             if (! preg_match('/[^a-zA-Z0-9_]+/', $name)) {
-                $this->dbi->query(
-                    'SET GLOBAL ' . $name . ' = ' . $escapedValue
-                );
+                $this->dbi->query('SET GLOBAL ' . $name . ' = ' . $escapedValue);
             }
         }
 
@@ -521,35 +527,27 @@ class Monitor
         }
 
         // Do not cache query
-        $sqlQuery = preg_replace(
-            '/^(\s*SELECT)/i',
-            '\\1 SQL_NO_CACHE',
-            $query
-        );
+        $sqlQuery = preg_replace('/^(\s*SELECT)/i', '\\1 SQL_NO_CACHE', $query);
 
         $this->dbi->tryQuery($sqlQuery);
         $return['affectedRows'] = $cached_affected_rows;
 
         $result = $this->dbi->tryQuery('EXPLAIN ' . $sqlQuery);
-        while ($row = $this->dbi->fetchAssoc($result)) {
-            $return['explain'][] = $row;
+        if ($result !== false) {
+            $return['explain'] = $result->fetchAllAssoc();
         }
 
         // In case an error happened
         $return['error'] = $this->dbi->getError();
 
-        $this->dbi->freeResult($result);
-
         if ($profiling) {
             $return['profiling'] = [];
             $result = $this->dbi->tryQuery(
-                'SELECT seq,state,duration FROM INFORMATION_SCHEMA.PROFILING'
-                . ' WHERE QUERY_ID=1 ORDER BY seq'
+                'SELECT seq,state,duration FROM INFORMATION_SCHEMA.PROFILING WHERE QUERY_ID=1 ORDER BY seq'
             );
-            while ($row = $this->dbi->fetchAssoc($result)) {
-                $return['profiling'][] = $row;
+            if ($result !== false) {
+                $return['profiling'] = $result->fetchAllAssoc();
             }
-            $this->dbi->freeResult($result);
         }
 
         return $return;
